sign_presentation_jwt

Function sign_presentation_jwt 

pub fn sign_presentation_jwt(
    vp: &VerifiablePresentation,
    signer: &dyn Signer,
    kid: &str,
    nonce: &str,
    audience: &str,
) -> Result<String>
Sign a VerifiablePresentation as a JWT.

The nonce and audience parameters are included as nonce and aud claims respectively, as required by the VP JWT spec.